@@ -26,7 +26,7 @@ class MainWindow : public QDialog, public Ui::MEConfig {
     Q_OBJECT
 
 public:
-    MainWindow(QWidget* parent = 0);
+    MainWindow(QWidget* parent = nullptr);
     ~MainWindow();
 
     // helpers
@@ -87,6 +87,7 @@ private slots:
 
 private:
     Cmd *shell;
+    QStringList users;
 
 };
 
